# Release Notes

### November 2025 - February 2026; versions 0.1.0 - 0.5.0.

From the first release with the Tibs and Mutibs classes to the first beta
with a completed initial API.

### November 2025; version 0.0.1.

#### Project start

The original version is a cut-down and rebranded version of bitformat.

Its main job is to reserve the name on PyPI.

